pub struct MarketOrderDelayedTradeClose {
pub source_transaction_id: Option<String>,
pub trade_id: Option<String>,
pub client_trade_id: Option<String>,
}Fields
source_transaction_id: Option<String>The Transaction ID of the DelayedTradeClosure transaction to which this Delayed Trade Close belongs to format: String representation of the numerical OANDA-assigned TransactionID
trade_id: Option<String>The ID of the Trade being closed format: The string representation of the OANDA-assigned TradeID. OANDA- assigned TradeIDs are positive integers, and are derived from the TransactionID of the Transaction that opened the Trade.
client_trade_id: Option<String>The Client ID of the Trade being closed format: The string representation of the OANDA-assigned TradeID. OANDA- assigned TradeIDs are positive integers, and are derived from the TransactionID of the Transaction that opened the Trade.
Implementations
Sourceimpl MarketOrderDelayedTradeClose
impl MarketOrderDelayedTradeClose
pub fn new() -> MarketOrderDelayedTradeClose
Sourcepub fn with_source_transaction_id(
self,
x: String,
) -> MarketOrderDelayedTradeClose
pub fn with_source_transaction_id( self, x: String, ) -> MarketOrderDelayedTradeClose
The Transaction ID of the DelayedTradeClosure transaction to which this Delayed Trade Close belongs to format: String representation of the numerical OANDA-assigned TransactionID
- param String
- return MarketOrderDelayedTradeClose
Sourcepub fn with_trade_id(self, x: String) -> MarketOrderDelayedTradeClose
pub fn with_trade_id(self, x: String) -> MarketOrderDelayedTradeClose
The ID of the Trade being closed format: The string representation of the OANDA-assigned TradeID. OANDA- assigned TradeIDs are positive integers, and are derived from the TransactionID of the Transaction that opened the Trade.
- param String
- return MarketOrderDelayedTradeClose
Sourcepub fn with_client_trade_id(self, x: String) -> MarketOrderDelayedTradeClose
pub fn with_client_trade_id(self, x: String) -> MarketOrderDelayedTradeClose
The Client ID of the Trade being closed format: The string representation of the OANDA-assigned TradeID. OANDA- assigned TradeIDs are positive integers, and are derived from the TransactionID of the Transaction that opened the Trade.
- param String
- return MarketOrderDelayedTradeClose